@@ -187,6 +187,65 @@ def fetch_2d_pose_data_alphapose_local_time_segment(
         carryover_poses.sort_values(['timestamp', 'assignment_id'], inplace=True)
     return current_poses, carryover_poses
 
+def fetch_all_data_json(
+    base_dir,
+    environment_id,
+    pose_track_3d_identification_inference_id,
+    download_position_data_inference_id,
+    download_position_data_trays_inference_id,
+    tray_events=None,
+    start=None,
+    end=None,
+    pose_processing_subdirectory='pose_processing',
+    indent=2,
+    output_path=None,
+    client=None,
+    uri=None,
+    token_uri=None,
+    audience=None,
+    client_id=None,
+    client_secret=None
+):
+    poses_3d_with_person_info_df = fetch_3d_poses_with_person_info(
+        base_dir=base_dir,
+        environment_id=environment_id,
+        pose_track_3d_identification_inference_id=pose_track_3d_identification_inference_id,
+        start=start,
+        end=end,
+        pose_processing_subdirectory=pose_processing_subdirectory,
+        client=client,
+        uri=uri,
+        token_uri=token_uri,
+        audience=audience,
+        client_id=client_id,
+        client_secret=client_secret
+    )
+    person_positions = fetch_person_positions_local(
+        base_dir=base_dir,
+        environment_id=environment_id,
+        start=start,
+        end=end,
+        download_position_data_inference_id=download_position_data_inference_id,
+        pose_processing_subdirectory=pose_processing_subdirectory
+    )
+    tray_positions = fetch_tray_positions_local(
+        base_dir=base_dir,
+        environment_id=environment_id,
+        start=start,
+        end=end,
+        download_position_data_trays_inference_id=download_position_data_trays_inference_id,
+        pose_processing_subdirectory=pose_processing_subdirectory
+    )
+    all_data_json = process_pose_data.viz_3d.convert_all_data_to_json(
+        poses_3d_with_person_info_df=poses_3d_with_person_info_df,
+        person_positions=person_positions,
+        tray_positions=tray_positions,
+        tray_events=tray_events,
+        indent=indent,
+        output_path=output_path
+    )
+    return all_data_json
+
 def fetch_3d_poses_with_person_info_json(
     base_dir,
     environment_id,
@@ -635,7 +694,6 @@ def fetch_tray_positions_local(
         'tray_name',
         'tray_part_number',
         'tray_serial_number',
-        'tray_name',
         'material_name',
         'material_transparent_classroom_id',
         'material_transparent_classroom_type',
